@@ -44,11 +44,11 @@ class Result:
 
 
 class Session:
-    START_TIMEOUT = 1
+    START_TIMEOUT = 5
     WAIT_TIMEOUT = 15
     SLEEP_THRESHOLD = 10
-    MAX_RETRIES = 5
-    ACKS_THRESHOLD = 8
+    MAX_RETRIES = 10
+    ACKS_THRESHOLD = 10
     PING_INTERVAL = 5
 
     def __init__(
@@ -185,7 +185,7 @@ class Session:
                 self.stored_msg_ids
             )
         except SecurityCheckMismatch as e:
-            log.info("Discarding packet: %s", e)
+            log.warning("Discarding packet: %s", e)
             await self.connection.close()
             return
 
@@ -307,7 +307,7 @@ class Session:
             result = self.results.pop(msg_id).value
 
             if result is None:
-                raise TimeoutError("Response timed out")
+                raise TimeoutError("Request timed out")
 
             if isinstance(result, raw.types.RpcError):
                 if isinstance(data, (raw.functions.InvokeWithoutUpdates, raw.functions.InvokeWithTakeout)):
